# -*- coding: utf-8 -*-

from akagi.contents import s3_content
from akagi.contents import local_file_content
from akagi.contents import spreadsheet_content
from akagi.contents import url_content

from akagi.contents.s3_content import S3Content
from akagi.contents.local_file_content import LocalFileContent
from akagi.contents.spreadsheet_content import SpreadsheetContent
from akagi.contents.url_content import URLContent
